Mean and standard deviation values on healthy and diseased tissues of chlorophyll fluorescence parameters \(F_0\) (minimum fluorescence) and \(F_m\) (maximum fluorescence) for a dataset of Arabidopsis thaliana plants infected with fungal pathogen data; parameters of the distribution of the ratio \(\displaystyle{\frac{F_v}{F_m} = \frac{F_m - F_0}{F_m}}\).
arabidopsisA data frame with 10 rows and 6 columns:
times of the acquisition of chlorophyll fluorescence images
indicates if the plant was inoculated: healthy (inoculated with water) or diseased (inoculated with the pathogen)
Mean and standard deviation values of the chlorophyll parameter \(F_0\)
Mean and standard deviation values of the chlorophyll parameter \(F_m\)
the \(\beta\), \(\rho\) and \(\delta_y\) parameters of the distribution of \(\displaystyle{\frac{F_v}{F_m} = \frac{F_m - F_0}{F_m}}\) (distributed according to a normal ratio distribution, see Details)
On each leaf picture, the \(F_0\) and \(F_m\) values are normally distributed. Hence, \(\displaystyle{\frac{F_0}{F_m}}\) is a ratio of two normal distributions.
Let \(\mu_{F_0}\) and \(\sigma_{F_0}\) the mean and standard deviation of \(F_0\) and \(\mu_{F_m}\) and \(\sigma_{F_m}\) the mean and standard deviation of \(F_m\). The parameters \(\beta\), \(\rho\) and \(\delta_y\) are given by: $$\beta = \frac{\mu_{F_0}}{\mu_{F_m}}$$ $$\rho = \frac{\sigma_{F_m}}{\sigma_{F_0}}$$ $$\delta_y = \frac{\sigma_{F_m}}{\mu_{F_m}}$$
El Ghaziri, A., Bouhlel, N., Sapoukhina, N., Rousseau, D., On the importance of non-Gaussianity in chlorophyll fluorescence imaging. Remote Sensing 15(2), 528 (2023). tools:::Rd_expr_doi("10.3390/rs15020528")
Pavicic, M., Overmyer, K., Rehman, A.u., Jones, P., Jacobson, D., Himanen, K. Image-Based Methods to Score Fungal Pathogen Symptom Progression and Severity in Excised Arabidopsis Leaves. Plants, 10, 158 (2021). tools:::Rd_expr_doi("10.3390/plants10010158")